
# Options

## Common options

`notebook-formats` - If exporting a Databricks run, the run's notebook revision can be saved in the specified formats (comma-delimited argument). Each format is saved in the notebooks folder of the run's artifact root directory as `notebook.{format}`. Supported formats are  SOURCE, HTML, JUPYTER and DBC. See Databricks [Export Format](https://docs.databricks.com/dev-tools/api/latest/workspace.html#notebookexportformat) documentation.

`use-src-user-id` -  Set the destination user ID to the source user ID. Source user ID is ignored when importing into Databricks since the user is automatically picked up from your Databricks access token.

`use-src-user-id` - Set the destination user field to the source user field. Only valid for open source MLflow.
When importing into Databricks, the source user field is ignored since it is automatically picked up from your Databricks access token.
There is no MLflow API endpoint to explicity set the user field for any objects such as Run or Experiment.

`import-source-tags` - Import source information for registered model and its versions ad tags in destination object.
See section below.

## MLflow Migration Source Tags

For ML governance purposes, original source run information is saved under the `mlflow_migration` tag prefix in the destination MLflow object.


For details see [governance.md](governance.md).
